==> plasma-nm-5.16.4.tar.xz: plasma-nm-5.16.4/libs/editor/settings/teamwidget.h <==
/*
    Copyright 2014 Lukas Tinkl <ltinkl@redhat.com>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef PLASMA_NM_TEAM_WIDGET_H
#define PLASMA_NM_TEAM_WIDGET_H

#include <QWidget>
#include <QMenu>
#include <QListWidgetItem>
#include <QDBusPendingCallWatcher>

#include "settingwidget.h"

#include <NetworkManagerQt/TeamSetting>

namespace Ui
{
class TeamWidget;
}

class Q_DECL_EXPORT TeamWidget : public SettingWidget
{
    Q_OBJECT
public:
    explicit TeamWidget(const QString & masterUuid, const NetworkManager::Setting::Ptr &setting = NetworkManager::Setting::Ptr(),
                        QWidget* parent = nullptr, Qt::WindowFlags f = {});
    ~TeamWidget() override;

    void loadConfig(const NetworkManager::Setting::Ptr &setting) override;

    QVariantMap setting() const override;

    bool isValid() const override;

private Q_SLOTS:
    void addTeam(QAction * action);
    void currentTeamChanged(QListWidgetItem * current, QListWidgetItem * previous);
    void teamAddComplete(QDBusPendingCallWatcher * watcher);

    void editTeam();
    void deleteTeam();

    void populateTeams();

    void importConfig();

private:
    QString m_uuid;
    Ui::TeamWidget * m_ui;
    QMenu * m_menu;
};

#endif // PLASMA_NM_TEAM_WIDGET_H

==> plasma-nm_5.18.6.orig.tar.xz: plasma-nm-5.18.6/libs/editor/settings/teamwidget.h <==
/*
    Copyright 2014 Lukas Tinkl <ltinkl@redhat.com>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef PLASMA_NM_TEAM_WIDGET_H
#define PLASMA_NM_TEAM_WIDGET_H

#include <QWidget>
#include <QMenu>
#include <QListWidgetItem>
#include <QDBusPendingCallWatcher>

#include "settingwidget.h"

#include <NetworkManagerQt/TeamSetting>

namespace Ui
{
class TeamWidget;
}

class Q_DECL_EXPORT TeamWidget : public SettingWidget
{
    Q_OBJECT
public:
    explicit TeamWidget(const QString & masterUuid, const QString &masterId,
                        const NetworkManager::Setting::Ptr &setting = NetworkManager::Setting::Ptr(),
                        QWidget* parent = nullptr, Qt::WindowFlags f = {});
    ~TeamWidget() override;

    void loadConfig(const NetworkManager::Setting::Ptr &setting) override;

    QVariantMap setting() const override;

    bool isValid() const override;

private Q_SLOTS:
    void addTeam(QAction * action);
    void currentTeamChanged(QListWidgetItem * current, QListWidgetItem * previous);
    void teamAddComplete(QDBusPendingCallWatcher * watcher);

    void editTeam();
    void deleteTeam();

    void populateTeams();

    void importConfig();

private:
    QString m_uuid;
    QString m_id;
    Ui::TeamWidget * m_ui;
    QMenu * m_menu;
};

#endif // PLASMA_NM_TEAM_WIDGET_H
